@@ -1,5 +1,5 @@
 /**
- * Copyright 2006-2015 the original author or authors.
+ * Copyright 2006-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,7 +22,6 @@ import org.objenesis.instantiator.android.Android18Instantiator;
 import org.objenesis.instantiator.basic.AccessibleInstantiator;
 import org.objenesis.instantiator.basic.ObjectInputStreamInstantiator;
 import org.objenesis.instantiator.gcj.GCJInstantiator;
-import org.objenesis.instantiator.jrockit.JRockitLegacyInstantiator;
 import org.objenesis.instantiator.perc.PercInstantiator;
 import org.objenesis.instantiator.sun.SunReflectionFactoryInstantiator;
 import org.objenesis.instantiator.sun.UnsafeFactoryInstantiator;
@@ -67,23 +66,11 @@ public class StdInstantiatorStrategy extends BaseInstantiatorStrategy {
          // times slower. So I prefer to use this one
          return new SunReflectionFactoryInstantiator<T>(type);
       }
-      else if(PlatformDescription.isThisJVM(JROCKIT)) {
-         if(VM_VERSION.startsWith("1.4")) {
-            // JRockit vendor version will be RXX where XX is the version
-            // Versions prior to 26 need special handling
-            // From R26 on, java.vm.version starts with R
-            if(!VENDOR_VERSION.startsWith("R")) {
-               // On R25.1 and R25.2, ReflectionFactory should work. Otherwise, we must use the
-               // Legacy instantiator.
-               if(VM_INFO == null || !VM_INFO.startsWith("R25.1") || !VM_INFO.startsWith("R25.2")) {
-                  return new JRockitLegacyInstantiator<T>(type);
-               }
-            }
-         }
-         // After that, JRockit became compliant with HotSpot
-         return new SunReflectionFactoryInstantiator<T>(type);
-      }
       else if(PlatformDescription.isThisJVM(DALVIK)) {
+         if(PlatformDescription.isAndroidOpenJDK()) {
+            // Starting at Android N which is based on OpenJDK
+            return new UnsafeFactoryInstantiator<T>(type);
+         }
          if(ANDROID_VERSION <= 10) {
             // Android 2.3 Gingerbread and lower
             return new Android10Instantiator<T>(type);
@@ -92,9 +79,13 @@ public class StdInstantiatorStrategy extends BaseInstantiatorStrategy {
             // Android 3.0 Honeycomb to 4.2 Jelly Bean
             return new Android17Instantiator<T>(type);
          }
-         // Android 4.3 and higher (hopefully)
+         // Android 4.3 until Android N
          return new Android18Instantiator<T>(type);
       }
+      else if(PlatformDescription.isThisJVM(JROCKIT)) {
+         // JRockit is compliant with HotSpot
+         return new SunReflectionFactoryInstantiator<T>(type);
+      }
       else if(PlatformDescription.isThisJVM(GNU)) {
          return new GCJInstantiator<T>(type);
       }
